Description: Новости Сочи, Адлера, Хосты и Лазаревского, онлайн видео
Keywords: вести сочи, новости сочи

Пятница, 04 декабря 2015
Организаторы сочинского Гран-при «Формула-1» снизили цены на билеты Сегодня, 4 декабря, в 12:30 стартует продажа билетов на третий российский Гран-при автогонок «Формула-1» сезона-2016, который будет проходить на «Сочи Автодроме» с 28 апреля по 1 мая. В преддверии начала продаж организаторы этапа анонсировали снижение цен на билеты.
Спасатели смогли достать сочинцев из разбитой машины Накануне, 3 декабря, на объездной дороге между тоннелями № 1 и № 2, в районе улицы Транспортной, произошло ДТП. Автомобиль ВАЗ-2107 врезался в грузовой автомобиль.
Мэр Сочи объявил новую дату начала горнолыжного сезона Вчера, 3 декабря, на пресс-конференции в Москве мэр Сочи Анатолий Пахомов сообщил, что официальное открытие зимнего сезона на горнолыжных курортах южной столицы запланировано на 19 декабря.
Более 20 улиц Большого Сочи останутся без света Сегодня, 4 декабря, в течение рабочего дня плановые отключения электроэнергии пройдут в нескольких проселках курорта, сообщает пресс-служба «Сочинских электрических сетей».

# Лента Новостей

## ГИБДД проверит сочинских водителей на наличие долгов

04.12.2015 14:23

На этой неделе сотрудники ОГИБДД УВД по г. Сочи совместно с судебными приставами начали проводить во всех районах курорта рейдовые мероприятия в рамках операции «Должник».

Подробнее...

## Молодой сочинский теннисист удостоен национальной премии

04.12.2015 13:44

В Москве прошла ежегодная церемония вручения премии «Русский кубок», в рамках которой Федерация тенниса России в различных номинациях отмечает лучших спортсменов, тренеров, менеджеров.

Подробнее...

## Сочинский певец стал «Серебряным голосом Кубани»

04.12.2015 12:57

Накануне, 3 декабря, в Краснодаре прошел финал самого масштабного творческого конкурса школьников региона — «Серебряный голос Кубани». Певческое соревнование, которое еще называют «кубанским Евровидением» собрало лучших исполнителей — 10 солистов и вокальных ансамблей.

Подробнее...

## Организаторы сочинского Гран-при «Формула-1» снизили цены на билеты

04.12.2015 12:19

Сегодня, 4 декабря, в 12:30 стартует продажа билетов на третий российский Гран-при автогонок «Формула-1» сезона-2016, который будет проходить на «Сочи Автодроме» с 28 апреля по 1 мая. В преддверии начала продаж организаторы этапа анонсировали снижение цен на билеты.

Подробнее...

## Спасатели смогли достать сочинцев из разбитой машины

04.12.2015 11:40

Накануне, 3 декабря, на объездной дороге между тоннелями № 1 и № 2, в районе улицы Транспортной, произошло ДТП. Автомобиль ВАЗ-2107 врезался в грузовой автомобиль.

Подробнее...

## Мэр Сочи объявил новую дату начала горнолыжного сезона

04.12.2015 11:06

Вчера, 3 декабря, на пресс-конференции в Москве мэр Сочи Анатолий Пахомов сообщил, что официальное открытие зимнего сезона на горнолыжных курортах южной столицы запланировано на 19 декабря.

Подробнее...

## Сочинские инвалиды хотят создать Центр психологической помощи

04.12.2015 10:27

Сегодня, 4 декабря, во многих сочинских школах пройдут необычные уроки физкультуры — с элементами паралимпийского спорта. Так на курорте решили поддержать Всероссийскую декаду инвалидов.

Подробнее...

## Более 20 улиц Большого Сочи останутся без света

04.12.2015 09:49

Сегодня, 4 декабря, в течение рабочего дня плановые отключения электроэнергии пройдут в нескольких проселках курорта, сообщает пресс-служба «Сочинских электрических сетей».

Подробнее...

## «Сочи» снова упустил победу в овертайме

04.12.2015 09:10

Накануне, 3 декабря, в ледовом дворце спорта «Большой» ХК «Сочи» принимал гостей из Латвии. Рижское «Динамо» оказалось сильнее хозяев льда, одержав победу в овертайме.

Подробнее...

## В Сочи будут судить вора, укравшего сейф с 7 млн рублей

04.12.2015 08:32

В Сочи завершено расследование уголовного дело по факту кражи, совершенной в особо крупном размере. Подозреваемый в этом преступлении рискует лишиться свободы на 10-летний срок.

Подробнее...

## Автобусный маршрут аэропорт Сочи – Красная Поляна откроется с середины декабря

03.12.2015 19:54

Прямой автобусный рейс свяжет Международный аэропорт Сочи и горнолыжные курорты. Автобусы туристического класса будут доставлять отдыхающих прямо к местам проживания - гостиницам и отелям Красной Поляны.

Подробнее...

## Хоккеисты «Сочи» снова готовы подать заявление в прокуратуру

03.12.2015 19:20

Сочинские хоккеисты снова готовят коллективное обращение в прокуратуру по поводу того, что несколько месяцев им не выплачивают зарплату. Об этом заявил агентству «Р-Спорт» нападающий команды Роман Людучин.

Подробнее...

## Причинами затопления федеральной трассы в Сочи занялась прокуратура

03.12.2015 18:55

В минувший понедельник был затоплен участок федеральной трассы Сочи-Адлер в микрорайоне Чкаловский. Сейчас ведутся работы по созданию дополнительной системы сброса дождевой воды, а причины затопления выясняет прокуратура.

Подробнее...

Страница 1 из 1886

Первая
Предыдущая
1
2
3
4
5
6
7
8
9
10
Следующая
Последняя

### Видео Вести Сочи

### Видео дня

### Последние комментарии

﻿

### Популярные новости

- Сотрудники торгового центра «Магнолия» переживают за свое будущее
- Штормовое предупреждение сохранится в Сочи до 4 декабря
- Красную Поляну занесло снегом
- Водителю, сбившему беременную женщину в Сочи, грозит 5 лет лишения свободы
- На Центральном рынке стали продавать хлеб и колбасу собственного производства

### Социальные сети

### Архив новостей

| 2015 |
| Декабрь |

| Пн | Вт | Ср | Чт | Пт | Сб | Вс
1 |  | 1 | 2 | 3 | 4 | 5 | 6
2 | 7 | 8 | 9 | 10 | 11 | 12 | 13
3 | 14 | 15 | 16 | 17 | 18 | 19 | 20
4 | 21 | 22 | 23 | 24 | 25 | 26 | 27
5 | 28 | 29 | 30 | 31 |  |  |

### Курс валют

﻿
USD
67,670 -0,099
EUR
73,672 1,932
Дата: 05.12.2015
Источник: ЦБ РФ

### Наши партнёры

### Последние объявления

- Грузчики-Регион93.Переезды.Такелаж.Транспорт. (Резюме / Сфера услуг)
- Продаю дом у моря (Купля/Продажа / Домовладения)
- Компьютерная помощь. Сочи, Адлер. Выезд к клиенту. (Электроника / Компьютерная техника)
- Выполню работы по отделке дагестанским камнем (Резюме / Сфера услуг)
- Установка, замена и ремонт замков в Сочи все р-ны ( / Разное)

### Счётчик посещений

Вверх

© 2011-2015. Территориальное отделение филиала ВГТРК «ГТРК «Кубань» в г. Сочи. Все права защищены. Полное или частичное копирование материалов запрещено. При согласованном использовании материалов сайта необходима ссылка (для электронных СМИ - гиперссылка) на ресурс.
Для детей старше 16 лет.